| Transition-package | R Documentation |
Analyse data from longitudinal studies to characterise changes in values of semi-quantitative outcome variables within individual subjects, using high performance C++ code to enable rapid processing of large datasets. A flexible methodology is available for codifying these state transitions.
Index: This package was not yet installed at build time.
Mark Eisler <mark.eisler@bristol.ac.uk>
Mark Eisler [aut, cre, cph] (ORCID: <https://orcid.org/0000-0001-6843-3345>), Ana Rabaza [aut] (ORCID: <https://orcid.org/0000-0002-9713-0797>)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.