| uniques | R Documentation |
uniques() identifies unique values for subjects, timepoints and test results in
longitudinal study data.
uniques(
object,
subject = "subject",
timepoint = "timepoint",
result = "result"
)
object |
a |
subject |
|
timepoint |
|
result |
|
See Transitions details.
Works for subject as either an integer vector or
a factor.
A list of three elements
1. |
An |
2. |
A |
3. |
An |
data.frame, Dates, ordered factor.
Other transitions:
PreviousDate,
PreviousResult,
Transitions
## Continuing example from `add_transitions()`
# subject, timepoint and result arguments all defaults and required types
# (native subject is factor)
uniques(Blackmore)
#
Blackmore <- transform(Blackmore, subject = as.integer(subject))
# subject now as integer
Blackmore |> str()
uniques(Blackmore)
rm(Blackmore)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.